@@ -88,13 +88,6 @@ class PWidgetBase(PSignalBase):
     fn_enable_get = None
     fn_enable_set = None
     
-    signals = (
-        SIGNAL_FOCUS_IN,
-        SIGNAL_FOCUS_OUT,
-    )
-    
-    setup_signals = None
-    
     def __init__(self, manager, parent, geometry=None, font=None):
         self.manager = manager
         manager.all_widgets.append(self)
@@ -106,6 +99,9 @@ class PWidgetBase(PSignalBase):
                 font = (font,)  # font name only is allowed
             self.set_font(*font)
     
+    def setup_signals(self):
+        pass  # subclasses can override if needed
+    
     def update_widget(self):
         """Placeholder for derived classes to implement.
         """
@@ -551,9 +547,7 @@ class PManagerBase:
     
     def setup_signals(self):
         for widget in self.all_widgets:
-            setup = widget.setup_signals
-            if callable(setup):
-                setup()
+            widget.setup_signals()
         for manager in self.sub_managers:
             manager.setup_signals()
         if self.handler_prefix:
