@@ -13,10 +13,14 @@ import functools
 from plib.ui.defs import *
 
 from .app import PWidgetBase
+from .focus import PFocusBase
 
 
-class PEditBase(PWidgetBase):
+class PEditBase(PFocusBase, PWidgetBase):
     """Base edit control class, defines standard API.
+    
+    Edit controls are the only ones that by default emit
+    focus in/out signals.
     """
     
     fn_get_text = None
