@@ -64,6 +64,8 @@ action_key_list = sorted(action_map.keys())
 # widgets are created
 
 def add_action(key, name, caption, description, icon):
+    if key in action_map:
+        raise RuntimeError("Key {} is already in use".format(key))
     action_map[key] = [name, caption, description, icon]
     action_key_list.append(key)
     action_key_list.sort()
@@ -72,7 +74,9 @@ def add_action(key, name, caption, description, icon):
 # Allow modifying existing actions
 
 def modify_action(key, name=None, caption=None, description=None, icon=None):
-    entry = action_map[key]
+    entry = action_map.get(key)
+    if not entry:
+        raise RuntimeError("Invalid action key: {}".format(key))
     items = (name, caption, description, icon)
     add_index = len(entry)
     for index, item in enumerate(items[:add_index]):
@@ -97,6 +101,10 @@ def pxdata(name,
             data = None
         if data:
             return data
+    if os.path.isfile(name):
+        with open(name, 'rb') as f:
+            data = f.read()
+        return data
 
 
 # Convenience functions for action properties
