@@ -21,9 +21,6 @@ from .app import PQtSequenceWidget
 class PTabWidget(PQtSequenceWidget, qt.QTabWidget, PTabWidgetBase):
     
     def __init__(self, manager, parent, tabs=None):
-        self._item = None
-        self._target = None
-        self._setting_index = False
         qt.QTabWidget.__init__(self, parent)
         PTabWidgetBase.__init__(self, manager, parent, tabs=tabs)
     
@@ -54,25 +51,5 @@ class PTabWidget(PQtSequenceWidget, qt.QTabWidget, PTabWidgetBase):
     def current_index(self):
         return self.currentIndex()
     
-    def _current_changed(self, index):
-        # Wrapper for tab changed signal.
-        if (not self._setting_index) and self._target:
-            self._target(index)
-    
-    def connect_target(self, signal, target):
-        super_method = super(PTabWidget, self).connect_target
-        if signal == SIGNAL_TABSELECTED:
-            # Hack to capture double firing of tab changed signal when
-            # tab is changed programmatically instead of by user
-            self._target = target
-            super_method(signal, self._current_changed)
-        else:
-            super_method(signal, target)
-    
     def set_current_index(self, index):
-        # Wrap the call to avoid double calling of signal handler, then
-        # make the call by hand.
-        self._setting_index = True
         self.setCurrentIndex(index)
-        self._setting_index = False
-        self._current_changed(index)
