@@ -30,9 +30,6 @@ class PQtListBoxBase(qt.QListWidget, PQtWidgetBase):
     #def item_height(self, index):
     #    return self.itemWidget(self.item(index)).height()
     
-    def item_text(self, item):
-        return item.text()
-    
     def current_index(self):
         return self.currentRow()
     
