@@ -19,16 +19,15 @@ from .app import PWxWidget
 
 
 wx_styles = {
-    PANEL_NONE: wx.NO_BORDER,
+    PANEL_PLAIN: wx.NO_BORDER,
     PANEL_BOX: wx.SIMPLE_BORDER,
     PANEL_RAISED: wx.RAISED_BORDER,
-    PANEL_SUNKEN: wx.SUNKEN_BORDER
+    PANEL_SUNKEN: wx.SUNKEN_BORDER,
 }
 
 wx_layouts = {
-    LAYOUT_NONE: wx.HORIZONTAL,
     LAYOUT_HORIZONTAL: wx.HORIZONTAL,
-    LAYOUT_VERTICAL: wx.VERTICAL
+    LAYOUT_VERTICAL: wx.VERTICAL,
 }
 
 
@@ -36,8 +35,8 @@ class PPanel(PWxWidget, wx.Panel, PPanelBase):
     
     _expand = True  # used by parent panel to determine placement
     
-    def __init__(self, manager, parent, align=ALIGN_JUST, layout=LAYOUT_NONE, contents=None,
-                 style=PANEL_NONE, margin=None, spacing=None):
+    def __init__(self, manager, parent, align=ALIGN_JUST, layout=LAYOUT_VERTICAL, contents=None,
+                 style=PANEL_PLAIN, margin=None, spacing=None):
         
         wx.Panel.__init__(self, parent, style=wx_styles[style])
         self._align = (align == ALIGN_JUST)
